@@ -6,8 +6,6 @@
 """
 __docformat__ = "restructuredtext en"
 
-import json
-
 from logilab.common.decorators import cached
 from logilab.common.date import todate
 
@@ -177,7 +175,7 @@ class Version(AnyEntity):
     def __json_encode__(self):
         data = super(Version, self).__json_encode__()
         data['state'] = self.cw_adapt_to('IWorkflowable').state
-        return json.dumps(data, cls=CubicWebJsonEncoder)
+        return data
 
 
 class VersionIUserFriendlyUniqueTogether(IUserFriendlyUniqueTogether):
