@@ -174,7 +174,10 @@ URL
             sect.append(self.format_field(attr, entity.printable_value(attr)))
         ctx['mainsection'] = '\n'.join(sect)
         description = entity.printable_value('description', format='text/plain')
-        description = normalize_text(description, 80)
+        if description and entity.description_format != 'text/rest':
+            # XXX don't try to wrap rest until we've a proper transformation (see
+            # #103822)
+            description = normalize_text(description, 80)
         ctx['description'] = description
         ctx['pname'] = entity.project.name
         ctx['purl'] = entity.project.absolute_url()
