@@ -1,7 +1,7 @@
 """Custom form for tracker
 
 :organization: Logilab
-:copyright: 2003-2011 LOGILAB S.A. (Paris, FRANCE), license is LGPL.
+:copyright: 2003-2012 LOGILAB S.A. (Paris, FRANCE), license is LGPL.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
@@ -9,7 +9,7 @@ __docformat__ = "restructuredtext en"
 from datetime import datetime
 
 from cubicweb.selectors import is_instance, match_transition, attribute_edited
-from cubicweb.web import uicfg, formfields
+from cubicweb.web import uicfg, formfields, eid_param
 from cubicweb.web.views import workflow, editviews
 from cubicweb.web.views.autoform import AutomaticEntityForm
 
@@ -36,8 +36,14 @@ def ticket_subj_rel_choices(rtype, version_state_restr):
         # it isn't, check if the entity provides a method to get correct values
         vocab = field.relvoc_init(form)
         if not entity.has_eid():
-            peids = form.linked_to['concerns', 'subject']
-            peid = peids and peids[0]
+            try:
+                peids = form.linked_to['concerns', 'subject']
+            except KeyError:
+                # copy
+                cteid = form.field_by_name(eid_param('__cloned_eid', entity.eid)).value
+                peid = form._cw.entity_from_eid(cteid, 'Ticket').project.eid
+            else:
+                peid = peids and peids[0]
             veid = None
         else:
             peid = entity.project.eid
